|Build Status| |Coverage Status|

Gisrep
======

The command line Github issues reporter, making requests with
`PyGithub <https://github.com/PyGithub/PyGithub>`__ and formatting the results with
`jinja2 <http://jinja.pocoo.org/docs/2.10/>`__.

Documentation
-------------

For guidance on installation and usage, check out the
`documentation <https://briggysmalls.github.io/gisrep/>`__.

Contributing
------------

You may contribute in several ways like creating new features, fixing
bugs or improving documentation and examples. `Find more information in
CONTRIBUTING.rst <CONTRIBUTING.rst>`__.

.. |Build Status| image:: https://travis-ci.org/briggySmalls/gisrep.svg?branch=master
   :target: https://travis-ci.org/briggySmalls/gisrep?branch=master
.. |Coverage Status| image:: https://coveralls.io/repos/github/briggySmalls/gisrep/badge.svg?branch=master
   :target: https://coveralls.io/github/briggySmalls/gisrep?branch=master
